### Erste Schritte

PDFMathTranslate ist ein leistungsstarkes PDF-Übersetzungstool. Sie können dieses Tool auf verschiedene Arten installieren und mit der Verwendung beginnen.

---

### Installation

1. [**Windows EXE**](./INSTALLATION_winexe.md) <small>Empfohlen für Windows</small>
2. [**Docker**](./INSTALLATION_docker.md) <small>Empfohlen für Linux</small>
3. [**uv** (ein Python-Paketmanager)](./INSTALLATION_uv.md) <small>Empfohlen für macOS</small>

---

### Verwendung

1. [Verwendung der **WebUI**](./USAGE_webui.md)
2. [Verwendung des **Zotero-Plugins**](https://github.com/guaguastandup/zotero-pdf2zh) (Drittanbieterprogramm)
3. [Verwendung der **Kommandozeile**](./USAGE_commandline.md)

<div align="right"> 
<h6><small>Ein Teil des Inhalts dieser Seite wurde von GPT übersetzt und kann Fehler enthalten.</small></h6>